Module pascal_string

Module pascal_string 

Structs

PascalString

Enums

InsertError
An error returned by insertion operations.
RemoveError
An error returned by removal operations.
ReplaceRangeError
An error returned by replace-range operations.
SplitOffError
An error returned by try_split_off.
TryFromBytesError
An error returned when a conversion from a &[u8] to a PascalString fails.
TryFromStrError
An error returned when a conversion from a &str to a PascalString fails.