ReplaceRangeError

Enum ReplaceRangeError 

pub enum ReplaceRangeError {
    OutOfBounds {
        start: usize,
        end: usize,
        len: usize,
    },
    NotCharBoundary {
        idx: usize,
    },
    TooLong,
}
An error returned by replace-range operations.

Variants



OutOfBounds

The range bounds are invalid or out of bounds.

Fields

start: usize
end: usize
len: usize


NotCharBoundary

The range start or end is not on a UTF-8 character boundary.

Fields

idx: usize


TooLong

The result would exceed the fixed capacity.