pub enum ReplaceRangeError {
OutOfBounds {
start: usize,
end: usize,
len: usize,
},
NotCharBoundary {
idx: usize,
},
TooLong,
}Expand description
An error returned by replace-range operations.
Variants
OutOfBounds
The range bounds are invalid or out of bounds.
NotCharBoundary
The range start or end is not on a UTF-8 character boundary.
TooLong
The result would exceed the fixed capacity.